#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 reducers
version:              3.12.5
visibility:           public
id:                   reducers-3.12.5-1FAJ7zl5r05C7v15aUNlbz
key:                  reducers-3.12.5-1FAJ7zl5r05C7v15aUNlbz
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/reducers/
synopsis:
    Semigroups, specialized containers and a general map/reduce framework

description:
    Semigroups, specialized containers and a general map/reduce framework.

category:             Data, Math, Numerical, Semigroups
abi:                  9f2602140fa7086b7c5c186b55a24faf
exposed:              True
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union

import-dirs:          /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/reducers-3.12.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-reducers
hs-libraries:         HSreducers-3.12.5-1FAJ7zl5r05C7v15aUNlbz
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    fingertree-0.1.6.3-KBNjSA1fZmt6Fw3Q9PrrZH
    hashable-1.4.7.0-LnVJu1JSZWR8SeekGz9T3N
    semigroupoids-6.0.2-AgzM3ab58xiIBS7x9trYsT text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9MqMq77Kwyw3AYghIevUCW

haddock-interfaces:   /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html:         /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

